@@ -1,6 +1,6 @@
 package Tapper::Schema::TestrunDB::Result::Testrun;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Schema::TestrunDB::Result::Testrun::VERSION = '5.0.0';
+$Tapper::Schema::TestrunDB::Result::Testrun::VERSION = '5.0.1';
 # ABSTRACT: Tapper - Containing Testruns
 
 use 5.010;
@@ -9,7 +9,7 @@ use warnings;
 
 use parent 'DBIx::Class';
 
-__PACKAGE__->load_components(qw/InflateColumn::DateTime Core/);
+__PACKAGE__->load_components(qw/InflateColumn::DateTime TimeStamp Core/);
 __PACKAGE__->table('testrun');
 __PACKAGE__->add_columns(
     'id', {
